@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 #----------------------------------------------------------------------------
 
@@ -91,7 +91,7 @@ my %definitions = (
   'conflicts'           => $module_map2,
 
   'optional_features'   => {
-    list        => {
+    'map'       => {
         ':key'  => { name => \&word,
             'map'   => { description        => { value => \&string },
                          requires_packages  => { value => \&string },
@@ -152,7 +152,7 @@ my %definitions = (
   'conflicts'           => $module_map2,
 
   'optional_features'   => {
-    list        => {
+    'map'       => {
         ':key'  => { name => \&word,
             'map'   => { description        => { value => \&string },
                          requires_packages  => { value => \&string },
@@ -221,6 +221,22 @@ my %definitions = (
   'build_requires'      => $module_map1,
   'conflicts'           => $module_map2,
 
+  'optional_features'   => {
+    'map'       => {
+        ':key'  => { name => \&word,
+            'map'   => { description        => { value => \&string },
+                         requires_packages  => { value => \&string },
+                         requires_os        => { value => \&string },
+                         excludes_os        => { value => \&string },
+                         requires           => $module_map1,
+                         recommends         => $module_map1,
+                         build_requires     => $module_map1,
+                         conflicts          => $module_map2,
+            }
+        }
+     }
+  },
+
   'provides'    => {
     'map'       => { ':key' => { name  => \&module,
                                  'map' => { file    => { mandatory => 1, value => \&file },
@@ -551,7 +567,7 @@ my $atom     = qr[a-z\d]i;
 my $domain   = qr((($atom(($atom|-)*$atom)?)\.)*([a-zA-Z](($atom|-)*$atom)?));
 my $ip       = qr((\d+)(\.(\d+)){3})(:(\d+))?;
 my $enc      = qr%[a-fA-F\d]{2};
-my $legal1   = qr[a-zA-Z\d\$\-_.+!*'(),]; #' - this comment is to avoid syntax highlighting issues
+my $legal1   = qr[a-zA-Z\d\$\-_.+!*'(),#]; #' - this comment is to avoid syntax highlighting issues
 my $legal2   = qr[;:@&=];
 my $legal3   = qr((($legal1|$enc)|$legal2)*);
 my $path     = qr\/$legal3(\/$legal3)*;
@@ -756,7 +772,7 @@ for Miss Barbell Productions, L<http://www.missbarbell.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (C) 2007,2008 Barbie for Miss Barbell Productions
+  Copyright (C) 2007-2010 Barbie for Miss Barbell Productions
 
   This module is free software; you can redistribute it and/or
   modify it under the same terms as Perl itself.
